@@ -401,7 +401,7 @@ public final class ConfigKeys {
 		public static final String ICFG_TRACKER_NAT_CHECK_TIMEOUT = "Tracker NAT Check Timeout";
 		public static final String BCFG_TRACKER_SEND_PEER_I_DS = "Tracker Send Peer IDs";
 		public static final String BCFG_TRACKER_PORT_UDP_ENABLE = "Tracker Port UDP Enable";
-		public static final String ICFG_TRACKER_PORT_UDP_VERSION = "Tracker Port UDP Version";
+		//public static final String ICFG_TRACKER_PORT_UDP_VERSION = "Tracker Port UDP Version";
 		public static final String BCFG_TRACKER_COMPACT_ENABLE = "Tracker Compact Enable";
 		public static final String BCFG_TRACKER_LOG_ENABLE = "Tracker Log Enable";
 		public static final String BCFG_TRACKER_KEY_ENABLE_SERVER = "Tracker Key Enable Server";
@@ -416,10 +416,16 @@ public final class ConfigKeys {
 
 	public static class Transfer {
 
-		public static final String ICFG_MAX_DOWNLOAD_SPEED_KBS = "Max Download Speed KBs";
-		public static final String ICFG_MAX_UPLOAD_SPEED_KBS = "Max Upload Speed KBs";
-		public static final String BCFG_ENABLE_SEEDINGONLY_UPLOAD_RATE = "enable.seedingonly.upload.rate";
-		public static final String ICFG_MAX_UPLOAD_SPEED_SEEDING_KBS = "Max Upload Speed Seeding KBs";
+		public static final String LCFG_MAX_DOWNLOAD_SPEED_KBS = "Max Download Speed KBs";
+		@Deprecated
+		public static final String ICFG_MAX_DOWNLOAD_SPEED_KBS = LCFG_MAX_DOWNLOAD_SPEED_KBS;
+		public static final String LCFG_MAX_UPLOAD_SPEED_KBS = "Max Upload Speed KBs";
+		@Deprecated
+		public static final String ICFG_MAX_UPLOAD_SPEED_KBS = LCFG_MAX_UPLOAD_SPEED_KBS;		
+		public static final String BCFG_ENABLE_SEEDINGONLY_UPLOAD_RATE = "enable.seedingonly.upload.rate";		
+		public static final String LCFG_MAX_UPLOAD_SPEED_SEEDING_KBS = "Max Upload Speed Seeding KBs";
+		@Deprecated
+		public static final String ICFG_MAX_UPLOAD_SPEED_SEEDING_KBS = LCFG_MAX_UPLOAD_SPEED_SEEDING_KBS;		
 		public static final String ICFG_MAX_UPLOADS_WHEN_BUSY_INC_MIN_SECS = "max.uploads.when.busy.inc.min.secs";
 		public static final String BCFG_BIAS_UPLOAD_ENABLE = "Bias Upload Enable";
 		public static final String ICFG_BIAS_UPLOAD_SLACK_KBS = "Bias Upload Slack KBs";
@@ -451,8 +457,12 @@ public final class ConfigKeys {
 		public static final String ICFG_SET_FILE_PRIORITY_REM_PIECE = "Set File Priority Remaining Pieces";
 		public static final String SCFG_IGNORE_PEER_PORTS = "Ignore.peer.ports";
 		public static final String BCFG_LAN_SPEED_ENABLED = "LAN Speed Enabled";
-		public static final String ICFG_MAX_LAN_UPLOAD_SPEED_K_BS = "Max LAN Upload Speed KBs";
-		public static final String ICFG_MAX_LAN_DOWNLOAD_SPEED_K_BS = "Max LAN Download Speed KBs";
+		public static final String LCFG_MAX_LAN_UPLOAD_SPEED_K_BS = "Max LAN Upload Speed KBs";
+		@Deprecated
+		public static final String ICFG_MAX_LAN_UPLOAD_SPEED_K_BS = LCFG_MAX_LAN_UPLOAD_SPEED_K_BS;
+		public static final String LCFG_MAX_LAN_DOWNLOAD_SPEED_K_BS = "Max LAN Download Speed KBs";
+		@Deprecated
+		public static final String ICFG_MAX_LAN_DOWNLOAD_SPEED_K_BS = LCFG_MAX_LAN_DOWNLOAD_SPEED_K_BS;
 	}
 
 	public static class AutoSpeed {
