@@ -413,6 +413,11 @@ DisplayFormatters
 		return formatByteCountToKiBEtc(n, rate, bTruncateZeros, -1);
 	}
 
+	public static int
+	getXinBBase()
+	{
+		return( force_si_values?16:(use_si_units?16:10));
+	}
 	public static int
 	getKinB()
 	{
