@@ -2,6 +2,7 @@ package org.gudy.bouncycastle.jce.interfaces;
 
 import java.math.BigInteger;
 import java.security.PrivateKey;
+import org.gudy.bouncycastle.jce.spec.ECParameterSpec;
 
 /**
  * interface for Elliptic Curve Private keys.
@@ -13,4 +14,8 @@ public interface ECPrivateKey
      * return the private value D.
      */
     public BigInteger getD();
+    // Resolve conflict between ECKey and potential defaults
+		@Override
+		ECParameterSpec getParams();
+
 }
