@@ -3,6 +3,7 @@ package org.gudy.bouncycastle.jce.interfaces;
 import java.security.PublicKey;
 
 import org.gudy.bouncycastle.math.ec.ECPoint;
+import org.gudy.bouncycastle.jce.spec.ECParameterSpec;
 
 /**
  * interface for elliptic curve public keys.
@@ -14,4 +15,8 @@ public interface ECPublicKey
      * return the public point Q
      */
     public ECPoint getQ();
+
+		// ElGamalPrivateKey.java
+		@Override
+		ECParameterSpec getParams();
 }
